Crate collage

Crate collage 

collage is a template engine for Rust, designed for writing HTML and similar markup languages.

Rendering is performed by the markup! macro and custom structs and enums can be rendered by implementing the Render trait.

Re-exports

pub use html_escape;

Macros

markup
Parses an alternative markup syntax into a FnOnce(&mut String) function.
markup_part
This is mostly used automatically by the markup! macro to render partial content. It can be used when manual control is required.

Traits

Render
The markup! macro will render interpolated content by wrapping it in this trait’s Render::render_to function.

Functions

doctype
The literal <!DOCTYPE html> element.