Re-exports
pub use html_escape;
Macros
- markup
- Parses an alternative markup syntax into a
FnOnce(&mutString) function. - markup_
part - This is mostly used automatically by the
markup!macro to render partial content. It can be used when manual control is required.
Traits
- Render
- The
markup!macro will render interpolated content by wrapping it in this trait’sRender::render_tofunction.
Functions
- doctype
- The literal
<!DOCTYPE html>element.